This function applies the spatiotemporal individual-level model of seasonal infectious disease transmission within the Susceptible-Exposed-Infectious-Recovered-Susceptible (SEIRS) framework, to real data. It employs a likelihood based Monte Carlo Expectation Conditional Maximization (MCECM) algorithm for parameter estimation and AIC calculation. This function requires two dataframes, named data and adjacency_matrix, along with the necessary parameters. Detailed information on the structure of these two datasets is provided in the package.
SeasEpi_Par_Est(
data,
adjacency_matrix,
DimCovInf,
DimCovSus,
tau0,
lambda0,
alphaS0,
delta0,
alphaT0,
InfPrd,
IncPrd,
NIterMC,
NIterMCECM,
zeta10,
zeta20,
T_cycle
)alphaS Estimate of alpha S
BetaCovInf Estimate of beta vector for the individual level infection covariate
BetaCovSus Estimate of beta vector for the areal susceptibility to first infection covariate
alphaT Estimate of alpha T
delta Estimate of delta
zeta1 Estimate of zeta1
zeta2 Estimate of zeta2
tau1 Estimate of tau
lambda1 Estimate of lambda
AIC AIC of the fitted GDILM SEIRS
Dataset. The dataset should exactly match the data file in the data folder, including all the columns with the same names.
Adjacency matrix representing the regions in the study area (0 if no connection between regions)
Dimensions of the individual infectivity covariate
Dimensions of the area-level susceptibility to initial infection covariate
Initial value for spatial precision
Initial value for spatial dependence
Initial value for the susceptibility intercept
Initial value for the spatial decay parameter
Initial value for the infectivity intercept
Infectious period that can be obtained either from the literature or by fitting an SEIRS model to the data
Incubation period that can be obtained either from the literature or by fitting an SEIRS model to the data
Number of MCMC iterations
Number of MCECM iterations
Initial value for the amplitude of the seasonal oscillation parameter (sin part)
Initial value for the phase of the seasonal oscillation parameter (cos part)
The duration of a complete seasonal cycle (e.g., 12 months for an annual cycle)
# \donttest{
data(data)
data(adjacency_matrix)
SeasEpi_Par_Est(data,adjacency_matrix,2,2,0.5, 0.5, 1, 0.1, 1, 1, 1, 20, 2,0.2,0.2,5)
# }
Run the code above in your browser using DataLab