Learn R Programming

SeasEpi (version 0.0.3)

SeasEpi_Sim_Par_Est: SeasEpi for a Simulation Study

Description

This function conducts a simulation study for spatiotemporal individual-level model of seasonal infectious disease transmission within the Susceptible-Exposed-Infectious-Recovered-Susceptible (SEIRS) framework, using a user-defined grid size. It applies a likelihood based Monte Carlo Expectation Conditional Maximization (MCECM) algorithm to estimate model parameters and compute the AIC.

Usage

SeasEpi_Sim_Par_Est(
  GridDim1,
  GridDim2,
  NPostPerGrid,
  MaxTimePand,
  tau0,
  lambda0,
  alphaS0,
  delta0,
  alphaT0,
  PopMin,
  PopMax,
  InfFraction,
  InfPrd,
  IncPrd,
  NIterMC,
  NIterMCECM,
  zeta10,
  zeta20,
  T_cycle
)

Value

alphaS Estimate of alpha S

BetaCovInf Estimate of beta vector for the individual level infection covariate

BetaCovSus Estimate of beta vector for the areal susceptibility to first infection covariate

alphaT Estimate of alpha T

delta Estimate of delta

zeta1 Estimate of zeta1

zeta2 Estimate of zeta2

tau1 Estimate of tau

lambda1 Estimate of lambda

AIC AIC of the fitted GDILM SEIRS

Arguments

GridDim1

First dimension of the grid

GridDim2

Second dimension of the grid

NPostPerGrid

Number of postal codes per grid cell

MaxTimePand

Last time point of the pandemic

tau0

Initial value for spatial precision

lambda0

Initial value for spatial dependence

alphaS0

Initial value for the susceptibility intercept

delta0

Initial value for the spatial decay parameter

alphaT0

Initial value for the infectivity intercept

PopMin

Minimum population per postal code

PopMax

Maximum population per postal code

InfFraction

Fraction of each grid cell's population to be infected

InfPrd

Infectious period that can be obtained either from the literature or by fitting an SEIRS model to the data

IncPrd

Incubation period that can be obtained either from the literature or by fitting an SEIRS model to the data

NIterMC

Number of MCMC iterations

NIterMCECM

Number of MCECM iterations

zeta10

Initial value for the amplitude of the seasonal oscillation parameter (sin part)

zeta20

Initial value for the phase of the seasonal oscillation parameter (cos part)

T_cycle

The duration of a complete seasonal cycle (e.g., 12 months for an annual cycle)

Examples

Run this code
# \donttest{
SeasEpi_Sim_Par_Est(5,5,10,30,0.7, 0.7, -1, 0.1, 0,40, 50,0.6, 5, 5, 10, 3,0.2,0.2,5)
# }

Run the code above in your browser using DataLab